import { jsx as _jsx } from "react/jsx-runtime";
import { useMemo } from 'react';
import TreeFile from './TreeFile';
import TreeFolder from './TreeFolder';
import { TreeContext } from './TreeContext';
import { sortChildren } from '../helpers';
import { buildClassName } from '../presets';
import { useDark } from 'rspress/runtime';
export const tuple = (...args) => args;
const FileTreeValueType = tuple('directory', 'file');
const directoryType = FileTreeValueType[0];
const defaultProps = {
    initialExpand: false,
    className: '',
};
const makeChildren = (value = []) => {
    if (!value || !value.length)
        return null;
    return value
        .sort((a, b) => {
        if (a.type !== b.type)
            return a.type !== directoryType ? 1 : -1;
        return `${a.name}`.charCodeAt(0) - `${b.name}`.charCodeAt(0);
    })
        .map((item, index) => {
        if (item.type === directoryType)
            return (_jsx(TreeFolder, { name: item.name, extra: item.extra, parentExpanded: [], children: makeChildren(item.files) }, `folder-${item.name}-${index}`));
        return (_jsx(TreeFile, { name: item.name, extra: item.extra, parentExpanded: [] }, `file-${item.name}-${index}`));
    });
};
const Tree = ({ children, onClick, initialExpand, initialExpandDepth, tree, className, ...props }) => {
    if (!tree)
        return null;
    const isImperative = Boolean(tree.length > 0);
    const onFileClick = (path) => {
        onClick && onClick(path);
    };
    const initialValue = useMemo(() => ({
        onFileClick,
        initialExpand,
        initialExpandDepth,
        isImperative,
    }), [initialExpand]);
    const customChildren = isImperative
        ? makeChildren(tree)
        : sortChildren(children, TreeFolder);
    const dark = useDark();
    return (_jsx(TreeContext.Provider, { value: initialValue, children: _jsx("div", { "data-dark": String(dark), className: buildClassName(), ...props, children: customChildren }) }));
};
Tree.defaultProps = defaultProps;
Tree.displayName = 'GeistTree';
export default Tree;
